from IgoTokenizer import IgoTokenizer
from TinySegmenterTokenizer import TinySegmenterTokenizer
try:
    from MeCabTokenizer import MeCabTokenizer
except:
    pass

